"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const error = new Error(`AWS Error`);
const sendEmail = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const sendRawEmail = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
jest.mock('@aws-sdk/client-ses', () => {
    return {
        SES: jest.fn().mockImplementation(() => {
            return {
                sendEmail,
                sendRawEmail,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const sesHelperMock = new helper_1.SESHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.SESHelper.name}.${sesHelperMock.SendEmailAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sesHelperMock.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SESHelper.name}.${sesHelperMock.SendEmailWithAttachmentsAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
//# sourceMappingURL=helper-rejects.spec.js.map